@@ -1,8 +1,12 @@
+use crate::builtins::utils::print_stdout_with_capture;
 use crate::history;
 use crate::libs;
 use crate::rcfile;
+use crate::shell::Shell;
+use crate::types::{Command, CommandLine, CommandResult};
 
-pub fn run() -> i32 {
+pub fn run(_sh: &mut Shell, cl: &CommandLine, cmd: &Command,
+           capture: bool) -> CommandResult {
     let mut info = vec![];
     const VERSION: &str = env!("CARGO_PKG_VERSION");
     info.push(("version", VERSION));
@@ -35,9 +39,13 @@ pub fn run() -> i32 {
     info.push(("built-with", env!("BUILD_RUSTC_VERSION")));
     info.push(("built-at", env!("BUILD_DATE")));
 
+    let mut lines = Vec::new();
     for (k, v) in &info {
         // longest key above is 12-char length
-        println!("{: >12}: {}", k, v);
+        lines.push(format!("{: >12}: {}", k, v));
     }
-    0
+    let buffer = lines.join("\n");
+    let mut cr = CommandResult::new();
+    print_stdout_with_capture(&buffer, &mut cr, cl, cmd, capture);
+    cr
 }
